mailr19085 - in /trunk: lib/algebra/ lib/frame_order/ lib/linear_algebra/ target_functions/ test_suite/shared_data/frame_order/c...


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on March 23, 2013 - 21:21:
Author: bugman
Date: Sat Mar 23 21:21:21 2013
New Revision: 19085

URL: http://svn.gna.org/viewcvs/relax?rev=19085&view=rev
Log:
Renamed the lib.algebra package to the more appropriate lib.linear_algebra.


Added:
    trunk/lib/linear_algebra/
      - copied from r19084, trunk/lib/algebra/
    trunk/test_suite/unit_tests/_lib/_linear_algebra/
      - copied from r19084, trunk/test_suite/unit_tests/_lib/_algebra/
Removed:
    trunk/lib/algebra/
    trunk/test_suite/unit_tests/_lib/_algebra/
Modified:
    trunk/lib/frame_order/matrix_ops.py
    trunk/target_functions/frame_order.py
    trunk/test_suite/shared_data/frame_order/cam/generate_base.py
    
trunk/test_suite/shared_data/frame_order/cam/iso_cone_torsionless/frame_order_matrix.py
    
trunk/test_suite/shared_data/frame_order/cam/pseudo_ellipse_free_rotor/frame_order_matrix.py
    trunk/test_suite/unit_tests/_lib/__init__.py
    trunk/test_suite/unit_tests/_lib/_frame_order/test_matrix_ops.py
    trunk/test_suite/unit_tests/_lib/_linear_algebra/test___init__.py
    trunk/test_suite/unit_tests/_lib/_linear_algebra/test_kronecker_product.py

Modified: trunk/lib/frame_order/matrix_ops.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/lib/frame_order/matrix_ops.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- trunk/lib/frame_order/matrix_ops.py (original)
+++ trunk/lib/frame_order/matrix_ops.py Sat Mar 23 21:21:21 2013
@@ -28,7 +28,7 @@
 from numpy.linalg import norm
 
 # relax module imports.
-from lib.algebra.kronecker_product import transpose_23
+from lib.linear_algebra.kronecker_product import transpose_23
 from lib.geometry.rotations import tilt_torsion_to_R
 
 

Modified: trunk/target_functions/frame_order.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/target_functions/frame_order.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- trunk/target_functions/frame_order.py (original)
+++ trunk/target_functions/frame_order.py Sat Mar 23 21:21:21 2013
@@ -44,7 +44,7 @@
 from lib.frame_order.pseudo_ellipse import 
compile_2nd_matrix_pseudo_ellipse, pcs_numeric_int_pseudo_ellipse, 
pcs_numeric_int_pseudo_ellipse_qrint
 from lib.frame_order.pseudo_ellipse_free_rotor import 
compile_2nd_matrix_pseudo_ellipse_free_rotor
 from lib.frame_order.pseudo_ellipse_torsionless import 
compile_2nd_matrix_pseudo_ellipse_torsionless, 
pcs_numeric_int_pseudo_ellipse_torsionless, 
pcs_numeric_int_pseudo_ellipse_torsionless_qrint
-from lib.algebra.kronecker_product import kron_prod
+from lib.linear_algebra.kronecker_product import kron_prod
 from lib.alignment.pcs import pcs_tensor
 from lib.geometry.rotations import euler_to_R_zyz, two_vect_to_R
 from lib.alignment.rdc import rdc_tensor

Modified: trunk/test_suite/shared_data/frame_order/cam/generate_base.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/shared_data/frame_order/cam/generate_base.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- trunk/test_suite/shared_data/frame_order/cam/generate_base.py (original)
+++ trunk/test_suite/shared_data/frame_order/cam/generate_base.py Sat Mar 23 
21:21:21 2013
@@ -35,7 +35,7 @@
 from pipe_control.mol_res_spin import spin_loop
 from pipe_control.interatomic import interatomic_loop
 from lib.geometry.coord_transform import cartesian_to_spherical
-from lib.algebra.kronecker_product import kron_prod
+from lib.linear_algebra.kronecker_product import kron_prod
 from lib.geometry.rotations import axis_angle_to_R, R_to_euler_zyz
 from prompt.interpreter import Interpreter
 from lib.io import open_write_file

Modified: 
trunk/test_suite/shared_data/frame_order/cam/iso_cone_torsionless/frame_order_matrix.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/shared_data/frame_order/cam/iso_cone_torsionless/frame_order_matrix.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- 
trunk/test_suite/shared_data/frame_order/cam/iso_cone_torsionless/frame_order_matrix.py
 (original)
+++ 
trunk/test_suite/shared_data/frame_order/cam/iso_cone_torsionless/frame_order_matrix.py
 Sat Mar 23 21:21:21 2013
@@ -4,7 +4,7 @@
 from numpy import array, float64, kron, zeros
 
 # relax module imports.
-from lib.algebra.kronecker_product import kron_prod
+from lib.linear_algebra.kronecker_product import kron_prod
 from lib.frame_order.format import print_frame_order_2nd_degree
 
 

Modified: 
trunk/test_suite/shared_data/frame_order/cam/pseudo_ellipse_free_rotor/frame_order_matrix.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/shared_data/frame_order/cam/pseudo_ellipse_free_rotor/frame_order_matrix.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- 
trunk/test_suite/shared_data/frame_order/cam/pseudo_ellipse_free_rotor/frame_order_matrix.py
 (original)
+++ 
trunk/test_suite/shared_data/frame_order/cam/pseudo_ellipse_free_rotor/frame_order_matrix.py
 Sat Mar 23 21:21:21 2013
@@ -1,7 +1,7 @@
 from numpy import array, float64, zeros
 
 from lib.frame_order.format import print_frame_order_2nd_degree
-from lib.algebra.kronecker_product import kron_prod
+from lib.linear_algebra.kronecker_product import kron_prod
 
 
 # Store the rotation matrices.

Modified: trunk/test_suite/unit_tests/_lib/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/__init__.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- trunk/test_suite/unit_tests/_lib/__init__.py (original)
+++ trunk/test_suite/unit_tests/_lib/__init__.py Sat Mar 23 21:21:21 2013
@@ -25,6 +25,7 @@
     '_auto_relaxation'
     '_frame_order'
     '_geometry'
+    '_linear_algebra'
     '_spectral_densities'
     '_text'
     'test_float',

Modified: trunk/test_suite/unit_tests/_lib/_frame_order/test_matrix_ops.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_frame_order/test_matrix_ops.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- trunk/test_suite/unit_tests/_lib/_frame_order/test_matrix_ops.py 
(original)
+++ trunk/test_suite/unit_tests/_lib/_frame_order/test_matrix_ops.py Sat Mar 
23 21:21:21 2013
@@ -28,7 +28,7 @@
 from lib.frame_order.format import print_frame_order_2nd_degree
 from lib.geometry.coord_transform import cartesian_to_spherical
 from lib.frame_order import *
-from lib.algebra.kronecker_product import transpose_23
+from lib.linear_algebra.kronecker_product import transpose_23
 from lib.order.order_parameters import iso_cone_theta_to_S
 from status import Status; status = Status()
 

Modified: trunk/test_suite/unit_tests/_lib/_linear_algebra/test___init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_linear_algebra/test___init__.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- trunk/test_suite/unit_tests/_lib/_linear_algebra/test___init__.py 
(original)
+++ trunk/test_suite/unit_tests/_lib/_linear_algebra/test___init__.py Sat Mar 
23 21:21:21 2013
@@ -25,15 +25,15 @@
 
 # relax module imports.
 from test_suite.unit_tests.package_checking import PackageTestCase
-import lib.geometry
+import lib.linear_algebra
 
 
 class Test___init__(PackageTestCase):
     """Unit tests for the lib.algebra package."""
 
     def setUp(self):
         """Set up for the package checking."""
 
-        self.package = lib.algebra
-        self.package_name = 'lib.algebra'
-        self.package_path = sys.path[0] + sep + 'lib' + sep + 'algebra'
+        self.package = lib.linear_algebra
+        self.package_name = 'lib.linear_algebra'
+        self.package_path = sys.path[0] + sep + 'lib' + sep + 
'lib.linear_algebra'

Modified: 
trunk/test_suite/unit_tests/_lib/_linear_algebra/test_kronecker_product.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_linear_algebra/test_kronecker_product.py?rev=19085&r1=19084&r2=19085&view=diff
==============================================================================
--- 
trunk/test_suite/unit_tests/_lib/_linear_algebra/test_kronecker_product.py 
(original)
+++ 
trunk/test_suite/unit_tests/_lib/_linear_algebra/test_kronecker_product.py 
Sat Mar 23 21:21:21 2013
@@ -25,7 +25,7 @@
 from unittest import TestCase
 
 # relax module imports.
-from lib.algebra.kronecker_product import *
+from lib.linear_algebra.kronecker_product import *
 
 
 class Test_kronecker_product(TestCase):
@@ -25,15 +25,15 @@
 
 class Test___init__(PackageTestCase):
-    """Unit tests for the lib.algebra package."""
+    """Unit tests for the lib.linear_algebra package."""
 
     def setUp(self):




Related Messages


Powered by MHonArc, Updated Sat Mar 23 21:40:02 2013